Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3677)

Unified Diff: chrome/browser/autofill/risk/fingerprint.h

Issue 12212057: [Autofill] Add ability to load Risk fingerprint data in AutofillDialogControllerImpl. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Mock harder Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/autofill/risk/fingerprint.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/autofill/risk/fingerprint.h
diff --git a/chrome/browser/autofill/risk/fingerprint.h b/chrome/browser/autofill/risk/fingerprint.h
index c7907e7d03e04cb5ce0143a6c2461be674f8bf75..e25a8ca8b5eca42763fc31006b41b2a54d112ab1 100644
--- a/chrome/browser/autofill/risk/fingerprint.h
+++ b/chrome/browser/autofill/risk/fingerprint.h
@@ -11,6 +11,10 @@
class PrefService;
+namespace content {
+class WebContents;
+}
+
namespace gfx {
class Rect;
}
@@ -26,16 +30,14 @@ class Fingerprint;
// Asynchronously calls |callback| with statistics that, collectively, provide a
// unique fingerprint for this (machine, user) pair, used for fraud prevention.
// The |gaia_id| should be the user id for Google's authentication system.
// The |window_bounds| should be the bounds of the containing Chrome window.
// The |content_bounds| should be the bounds of the web contents view for the
// page the user is interacting with. The |prefs| should reflect the active
// Chrome profile's user preferences.
void GetFingerprint(
int64 gaia_id,
const gfx::Rect& window_bounds,
- const gfx::Rect& content_bounds,
- const WebKit::WebScreenInfo& screen_info,
+ const content::WebContents& web_contents,
const PrefService& prefs,
const base::Callback<void(scoped_ptr<Fingerprint>)>& callback);
« no previous file with comments | « no previous file | chrome/browser/autofill/risk/fingerprint.cc » ('j') | no next file with comments »
@@ -26,16 +30,14 @@ class Fingerprint;
// Asynchronously calls |callback| with statistics that, collectively, provide a
// unique fingerprint for this (machine, user) pair, used for fraud prevention.
-// The |gaia_id| should be the user id for Google's authentication system.
-// The |window_bounds| should be the bounds of the containing Chrome window.
-// The |content_bounds| should be the bounds of the web contents view for the
-// page the user is interacting with. The |prefs| should reflect the active
-// Chrome profile's user preferences.
+// |gaia_id| should be the user id for Google's authentication system.
+// |window_bounds| should be the bounds of the containing Chrome window.
+// |web_contents| should be the host for the page the user is interacting with.
+// |prefs| should reflect the active Chrome profile's user preferences.
void GetFingerprint(
int64 gaia_id,

Powered by Google App Engine
This is Rietveld 408576698